tests.test_structure module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- tests »
- tests package »

# tests.test_structure module

## tests.test_graphs

Tests graph generation.

class `tests.test_structure.` `TestDMPartitionGraphs`

  Bases: `object`

  Test device mapper partition graphs.

  `test_complete`()

    Assert that the graph has no cycles.

class `tests.test_structure.` `TestPartitionGraphs`

  Bases: `object`

  Test the partition graph.

  `test_complete`()

    The number of nodes in the graph is strictly greater than the number of partition devices, as partitions have to belong to some device.

class `tests.test_structure.` `TestSpindleGraphs`

  Bases: `object`

  Test spindle graphs.

  `test_complete`()

    Assert that the graph has no cycles.

class `tests.test_structure.` `TestSysfsGraphs`

  Bases: `object`

  Test building various graphs.

  `test_complete`()

    There is an equivalence between the nodes in the graph and the devices graphed.

    Moreover, all nodes have node_type DEVICE_PATH and all edges have type SLAVE.

class `tests.test_structure.` `TestSysfsTraversal`

  Bases: `object`

  An empty test class which is always skipped.

  `pytestmark` = [<MarkDecorator 'skipif' {'args': (True,), 'kwargs': {'reason': u'no slaves or holders data for tests'}}>]
  `test_dummy`()

    A dummy test, for which pytest can show a skip message.

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- tests »
- tests package »